@@ -7,13 +7,15 @@ import config as user_config
 
 class ConfigTestCase(unittest.TestCase):
 
-    def test_init_from_file(self):
+    def test_from_pyfile(self):
         dirname = os.path.dirname(__file__)
         path = os.path.join(dirname, 'config.py')
-        config = Config.from_path(path)
+        config = Config()
+        config.from_pyfile(path)
         self.assertEqual(config.MAX_LOAD, 20)
 
-    def test_init_from_module(self):
+    def test_from_object(self):
         user_config.KUYRUK_MAX_LOAD = 21
-        config = Config(user_config)
+        config = Config()
+        config.from_object(user_config)
         self.assertEqual(config.MAX_LOAD, 21)
